# haidra-core

The core python library containing essential shared utilities and components for the frameworks under the Haidra umbrella.

## haidra_core.ai_horde

Contains core environment setup and configuration for projects in the AI-Horde ecosystem.

### Settings

- `AIHordeClientSettings`: The base class for all AI Horde client environment settings.
    - `AIHordeWorkerSettings`: A subclass specifically designed for configuring worker nodes.
